@@ -4,6 +4,7 @@
 This module contains the controller and key handling logic of turses.
 """
 
+import signal
 import logging
 from gettext import gettext as _
 from functools import partial, wraps
@@ -105,6 +106,7 @@ class KeyHandler(object):
             'reply':             self.controller.reply,
             'retweet':           self.controller.retweet,
             'retweet_and_edit':  self.controller.manual_retweet,
+            'retweet_and_fav':   self.controller.retweet_and_favorite,
             'delete_tweet':      self.controller.delete_tweet,
             'follow_selected':   self.controller.follow_selected,
             'follow_user':       self.controller.follow_user,
@@ -262,9 +264,16 @@ class Controller(Observer):
         # Subscribe to model updates
         self.timelines.subscribe(self)
 
+        signal.signal(signal.SIGCONT, self.handle_sigcont)
+
     def start(self):
         self.main_loop()
 
+    def handle_sigcont(self, signum, stack_frame):
+        self.loop.screen.stop()
+        self.loop.screen.start()
+        self.redraw_screen()
+
     def authenticate_api(self):
         self.info_message(_('Authenticating API'))
 
@@ -1006,6 +1015,9 @@ class Controller(Observer):
             self.error_message(_('You can\'t retweet direct messages'))
             return
 
+        self._retweet(status)
+
+    def _retweet(self, status):
         retweet_posted = partial(self.info_message,
                                  _('Retweet posted'))
         retweet_post_failed = partial(self.error_message,
@@ -1026,6 +1038,17 @@ class Controller(Observer):
         else:
             self.error_message(_('Tweet too long for manual retweet'))
 
+    @has_active_status
+    def retweet_and_favorite(self):
+        status = self.timelines.active_status
+
+        if is_DM(status):
+            self.error_message(_('You can\'t retweet or favorite direct messages'))
+            return
+
+        self._retweet(status)
+        self._favorite(status)
+
     @has_active_status
     def reply(self):
         status = self.timelines.active_status
@@ -1187,6 +1210,9 @@ class Controller(Observer):
     def favorite(self):
         status = self.timelines.active_status
 
+        self._favorite(status)
+
+    def _favorite(self, status):
         favorite_error = partial(self.error_message,
                                  _('Failed to mark tweet as favorite'))
         favorite_done = partial(self.info_message,
